.. :changelog:

History
-------

0.1.0 (2014-03-01)
++++++++++++++++++

* First release on PyPI.

0.1.1 (2014-03-10)
++++++++++++++++++

* Minor bugfixes in the example application: incorrect reference to static files location.
